@@ -1,7 +1,5 @@
-from autoarray.structures.grids.coordinates import (
-    GridCoordinates,
-    GridCoordinatesUniform,
-)
+from autoarray.structures.grids.coordinates import GridCoordinates
+from autoarray.structures.grids.coordinates import GridCoordinatesUniform
 from autoarray.structures.grids.iterate import GridIterate
 from . import exc
 from . import plot
@@ -28,6 +26,8 @@ from .inversion.mappers import mapper as Mapper
 from .inversion.pixelizations import SettingsPixelization
 from .mask.mask_1d import Mask1D
 from .mask.mask_2d import Mask2D
+from .mock import mock
+from .mock import fixtures
 from .operators.convolver import Convolver
 from .operators.convolver import Convolver
 from .operators.transformer import TransformerDFT
@@ -55,4 +55,4 @@ from autoconf import conf
 
 conf.instance.register(__file__)
 
-__version__ = '0.14.11'
+__version__ = '0.14.12'
